package com.ebei.device.asset.weixin.contorller;

import com.ebei.device.asset.weixin.config.CommProperties;
import com.ebei.device.asset.weixin.util.ExceptionUtils;
import com.ebei.device.asset.weixin.util.HttpRequestUtils;
import com.ebei.device.asset.weixin.util.ResponseEx;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.rendering.PDFRenderer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.Base64Utils;
import org.springframework.web.bind.annotation.*;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : AssetRectifyController
 * @Description : 整改对应 前端控制器
 * @Date : 2021-04-12 18:33
 */

@RestController
@RequestMapping("/assetRectify")
@Api(value = "assetRectify" , description = "整改相关接口")
@Slf4j
public class AssetRectifyController {

    @Autowired
    CommProperties commProperties;

    @ApiOperation(value="获取pdf转换为图片list")
    @GetMapping("/getPdfToImage/{taskId}")
    public ResponseEx<Object> getPdfToImage(@PathVariable Long taskId ) throws Exception {
        InputStream inputStream = null;
        try {
             inputStream = HttpRequestUtils.getUrlConnection(commProperties.getRtwgOaPdfUrl()+taskId+"?preView=true", 1024*1024).getInputStream();
        }catch (Exception e){
            log.error(ExceptionUtils.getExceptionDetail(e));
            e.printStackTrace();
            return ResponseEx.createError(taskId+"该任务没有签名图片");
        }
        PDDocument pdDocument = PDDocument.load(inputStream);
        int pageCount = pdDocument.getNumberOfPages();
        PDFRenderer pdfRenderer = new PDFRenderer(pdDocument);

        List<Map<String, Object>> resultinfo = new ArrayList<Map<String, Object>>();
        Map<String, Object> obj = null;
        for (int pageIndex = 0; pageIndex < pageCount; pageIndex++) {
            // BufferedImage imageb = pdfRenderer.renderImageWithDPI(pageIndex, 105, ImageType.RGB);
            // 第二个参数数字越大越清晰
            BufferedImage bufferedImage = null;
            try {
                bufferedImage = pdfRenderer.renderImageWithDPI(pageIndex, 150);
                ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
                ImageIO.write(bufferedImage, "jpg", outputStream);// 写入流
                obj = new HashMap<String, Object>();
                obj.put("index", pageIndex);
                obj.put("pic", Base64Utils.encodeToString(outputStream.toByteArray()));
                resultinfo.add(obj);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        pdDocument.close();
        return ResponseEx.createSuccess(resultinfo);
    }

    @RequestMapping(value="/exportPDF/{taskId}",method = {RequestMethod.GET,RequestMethod.POST})
    public ResponseEx<String> createHardwarePDF(@PathVariable("taskId") Long taskId) throws Exception {
        String remoteFilePath =commProperties.getRtwgOaPdfUrl() +taskId+"?preView=true";
        return ResponseEx.createSuccess(200, remoteFilePath);
    }

}
