
package com.ebei.device.asset.weixin.contorller;

import com.ebei.device.asset.weixin.util.FileDownUtil;
import com.ebei.device.asset.weixin.util.FileUploadDownloadUtil;
import com.ebei.device.asset.weixin.util.ResponseEx;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.http.HttpResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.InputStream;
import java.net.URLDecoder;
import java.text.SimpleDateFormat;
import java.util.*;


/**
 * <p>
 * 机房位置 前端控制器
 * </p>
 * @author yangsm
 * @since 2018-08-16
 */
@RestController
@RequestMapping("/common")
@Api(value = "common" , description = "公共上传下载附件controller")
public class CommonController {
	private final static Logger logger = LoggerFactory.getLogger(CommonController.class);
	
	@ApiOperation(value = "上传文件(<input type='file' name='file'>)")
	@PostMapping("/uploadFile")
	public ResponseEx uploadFile(@RequestParam MultipartFile[] file, HttpServletRequest request) {
		Map<String,Object> resultMap;
		List<Map<String,Object>> resultList = new ArrayList<>();
		for(MultipartFile fileOne : file){
            try {
                String uuid = UUID.randomUUID().toString();
                String fileName = fileOne.getOriginalFilename();
                //上传文件
                SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                //上传到文件服务器
                boolean success = FileUploadDownloadUtil.commonFileUpload( uuid,fileOne.getInputStream(), dateFormat, fileOne.getOriginalFilename());
                if (!success) {
                    return ResponseEx.createError("文件上传失败");
                } else {
                    String filePath = FileUploadDownloadUtil.getRemoteFilePath(request,uuid);
                    String fileFormat = fileName.substring(fileName.lastIndexOf(".") + 1);
                    String fileType;
                    if("jpgpngjpeggif".indexOf(fileFormat)!=-1){
                        fileType = "1";
                    }else if("3gpmp4avimpgwav".indexOf(fileFormat)!=-1){
                        fileType = "2";
                    }else if("mp3amr".indexOf(fileFormat)!=-1){
                        fileType = "3";
                    }else if("docxlspptdocxxlsxpptxpdf".indexOf(fileFormat)!=-1){
                        fileType = "5";
                    }else {
                        fileType = "4";
                    }
                    resultMap = new HashMap<>();
                    resultMap.put("fileId",uuid);
                    resultMap.put("fileName",fileName);
                    resultMap.put("filePath",filePath);
                    resultMap.put("fileType",fileType);
                    resultList.add(resultMap);
                }
            } catch (Exception e) {
                logger.error("文件上传异常",e);
                return ResponseEx.createError("文件上传失败");
            }
		}
		return ResponseEx.createSuccess(resultList);
	}

	/**
	 * Discription :附件下载 void
	 */
	@ApiOperation(value = "下载附件")
	@GetMapping("/downFile")
	public void downFile(String fileId,String fileName, HttpServletResponse response) {
		logger.info("[服务器下载附件: downFile fileId:{}]" ,fileId);
        try {
            HttpResponse fileManagerResponse = FileUploadDownloadUtil.getFileManagerResponse(fileId);
            if(fileName == null){
                fileName = fileManagerResponse.getFirstHeader("filename").getValue();
                fileName = URLDecoder.decode(fileName, "UTF-8");
            }
            InputStream is = fileManagerResponse.getEntity().getContent();
//		    byte[] content = FileUploadDownloadUtil.fileMakeLocal(fileId);
            //输出到客户端
            FileDownUtil.downFile(is, fileName);
        } catch (Exception e) {
            logger.info("文件下载失败！{}",e);
        }

    }
	/**
	 * Discription :附件下载 void
	 */
	@ApiOperation(value = "获取文件URL")
	@GetMapping("/getFilePath")
	public ResponseEx<String> downFile(String fileId) {
		logger.info("[服务器下载附件: downFile fileId:{}]" ,fileId);
		return ResponseEx.createSuccess(FileUploadDownloadUtil.getRemoteFilePath(fileId,"127.0.0.1"));
			
	}
}
